//   Copyright 2012 Georg-August-Universität Göttingen, Germany
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

package de.ugoe.cs.autoquest.plugin.html.guimodel;

import de.ugoe.cs.autoquest.eventcore.guimodel.IGUIElementSpec;

/**
 * <p>
 * base class for all GUI element specifications in the context of HTML
 * </p>
 * 
 * @author Patrick Harms
 */
public class HTMLGUIElementSpec implements IGUIElementSpec {

    /**
     * <p>
     * default serial version UID
     * </p>
     */
    private static final long serialVersionUID = 1L;
    
    /**
     * <p>
     * the type of GUI element represented by this specification, which is usually the tag name of
     * the HTML GUI element
     * </p>
     */
    private String type;

    /**
     * <p>
     * the hashCode of this GUI element specification
     * </p>
     */
    private int hashCode;
    
    /**
     * <p>
     * instantiated the specification with the type, i.e., tag name of the represented GUI element
     * </p>
     *
     * @param type  the type, i.e., tag name of the represented GUI element
     * 
     * @throws IllegalArgumentException if the provided type is null
     */
    public HTMLGUIElementSpec(String type, int hashCode) {
        if (type == null) {
            throw new IllegalArgumentException("type must not be null");
        }

        this.type = type;
        this.hashCode = hashCode;
    }

    /* (non-Javadoc)
     * @see de.ugoe.cs.autoquest.eventcore.guimodel.IGUIElementSpec#getType()
     */
    @Override
    public String getType() {
        return type;
    }

    /* (non-Javadoc)
     * @see de.ugoe.cs.autoquest.eventcore.guimodel.IGUIElementSpec#getSimilarity(IGUIElementSpec)
     */
    @Override
    public boolean getSimilarity(IGUIElementSpec other) {
        if (other instanceof HTMLGUIElementSpec) {
            HTMLGUIElementSpec otherSpec = (HTMLGUIElementSpec) other;
            return type.equals(otherSpec.type);
        }
        
        return false;
    }

    /* (non-Javadoc)
     * @see de.ugoe.cs.autoquest.eventcore.guimodel.IGUIElementSpec#getTypeHierarchy()
     */
    @Override
    public String[] getTypeHierarchy() {
        return new String[] { type };
    }

    /* (non-Javadoc)
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        return hashCode;
    }

}
